# Pull Request Template

This template should be used for making any pull requests.

## Goal

Here, describe the goal of the pull request, i.e. what does it seek to address? Does this pull request fix an existing bug, or create a new feature? Why are the changes proposed by this pull request necessary?

## Specifics

Here, describe the specific changes to the repository suggested by this pull request. Which modules/methods/etc. were added or edited, and why? Have any new dependencies been introduced, and why?

## Verification

Here, describe steps taken to verify that the pull request is up to the standards of the repository. Were the suggested changes fully documented and tested, and do they match the existing code style? How exactly was this verification completed?
